//==============================================================================
// maze_test3.pov
// 02/08/2012
// Robert W. McGregor, www.mcgregorfineart.com
//------------------------------------------------------------------------------ 
// Description: Maze cubes AO
//------------------------------------------------------------------------------ 
// Command-line: +w1280 +h720 +a0.1 +r3
//==============================================================================

#version 3.7;

#include "rwm_maze.inc"

default { finish { ambient 0 specular 0 emission 0 diffuse 0.8 reflection 0 } }

//------------------------------------------------------------------------------ 
// Scene/Render Configuration 
//------------------------------------------------------------------------------ 

#declare floorY = -14;
#declare R_Maze = seed(1963);

global_settings { 
   assumed_gamma 1
   radiosity {
      brightness      1 
      recursion_limit 1  // keep at 1 bounce for deeper AO shadows
      pretrace_start  16/image_width
      pretrace_end    4/image_width
      count           1000
      error_bound     0.125/2         
      nearest_count   20
      normal          off 
      always_sample   off
   }
}

//------------------------------------------------------------------------------ 
// Camera 
//------------------------------------------------------------------------------ 

#declare Cam_Loc = <0, 20, -50>*0.85;

camera {  
   location Cam_Loc                                
   look_at  <-5.5, -8, 0>
   right x*image_width/image_height 
   angle 70
   rotate z*3 // slight camera tilt
}                     
// increased contrast trick
sphere { Cam_Loc, 1 pigment{ rgb 1 transmit 5 } }

//------------------------------------------------------------------------------ 
// Environment
//------------------------------------------------------------------------------ 

plane { z, 1000 hollow no_shadow 
   pigment {rgb 1} 
   finish { emission 0.025 ambient 0 diffuse 0 } 
}
background { rgb 0.01 }

#declare tex = texture {
   pigment { rgb 2 }
   normal { agate 0.075 scale 0.1 }
   finish { reflection 0 diffuse 8 }
}

//-----------------------------------------------------------------------------
// Maze34
//-----------------------------------------------------------------------------
#declare rez = 34;
#declare rad = 0.5;

#declare Maze = array[6];
#declare Maze[0] = BuildMaze(rez, rez, rad)
#declare Maze[1] = BuildMaze(rez, rez, rad)
#declare Maze[2] = BuildMaze(rez, rez, rad)
#declare Maze[3] = BuildMaze(rez, rez, rad)
#declare Maze[4] = BuildMaze(rez, rez, rad)
#declare Maze[5] = BuildMaze(rez, rez, rad)

#declare MazeCube34 = union {
   object { Maze[0] scale y*0.25 translate -y*rez/2}
   object { Maze[1] scale y*0.25 translate y*rez/2}
   object { Maze[2] scale y*0.25 rotate x*90 translate z*rez/2}
   object { Maze[3] scale y*0.25 rotate x*90 translate -z*rez/2}
   object { Maze[4] scale y*0.25 rotate z*90 translate x*rez/2}
   object { Maze[5] scale y*0.25 rotate z*90 translate -x*rez/2}
   interior { ior 1.5 }
   scale 0.5
   rotate <0, 40, 0>
}

#local _min34 = min_extent(MazeCube34);
union {
   object { MazeCube34 texture { tex } }
   translate <-rez*0.6, floorY-_min34.y, 0>
}

//-----------------------------------------------------------------------------
// Maze21
//-----------------------------------------------------------------------------
#declare rez = 21;
#declare rad = 0.5;

#declare Maze = array[6];
#declare Maze[0] = BuildMaze(rez, rez, rad)
#declare Maze[1] = BuildMaze(rez, rez, rad)
#declare Maze[2] = BuildMaze(rez, rez, rad)
#declare Maze[3] = BuildMaze(rez, rez, rad)
#declare Maze[4] = BuildMaze(rez, rez, rad)
#declare Maze[5] = BuildMaze(rez, rez, rad)

#declare MazeCube21 = union {
   object { Maze[0] scale y*0.25 translate -y*rez/2}
   object { Maze[1] scale y*0.25 translate y*rez/2}
   object { Maze[2] scale y*0.25 rotate x*90 translate z*rez/2}
   object { Maze[3] scale y*0.25 rotate x*90 translate -z*rez/2}
   object { Maze[4] scale y*0.25 rotate z*90 translate x*rez/2}
   object { Maze[5] scale y*0.25 rotate z*90 translate -x*rez/2}
   interior { ior 1.5 }
   scale 0.5
   rotate <0, 25, 0>
}

#local _min21 = min_extent(MazeCube21);
union {
   object { MazeCube21 texture { tex } }
   translate <rez*0.2, floorY-_min21.y, rez>
}
                                              
//-----------------------------------------------------------------------------
// Maze13
//-----------------------------------------------------------------------------

#declare rez = 13;
#declare rad = 0.5;

#declare Maze = array[6];
#declare Maze[0] = BuildMaze(rez, rez, rad)
#declare Maze[1] = BuildMaze(rez, rez, rad)
#declare Maze[2] = BuildMaze(rez, rez, rad)
#declare Maze[3] = BuildMaze(rez, rez, rad)
#declare Maze[4] = BuildMaze(rez, rez, rad)
#declare Maze[5] = BuildMaze(rez, rez, rad)

#declare MazeCube13 = union {
   object { Maze[0] scale y*0.25 translate -y*rez/2}
   object { Maze[1] scale y*0.25 translate y*rez/2}
   object { Maze[2] scale y*0.25 rotate x*90 translate z*rez/2}
   object { Maze[3] scale y*0.25 rotate x*90 translate -z*rez/2}
   object { Maze[4] scale y*0.25 rotate z*90 translate x*rez/2}
   object { Maze[5] scale y*0.25 rotate z*90 translate -x*rez/2}
   interior { ior 1.5 }
   scale 0.5
   rotate <0, -10, 0>
}

#local _min13 = min_extent(MazeCube13);
union {
   object { MazeCube13 texture { tex } }
   translate <rez*1.5, floorY-_min13.y, rez>
}

//-----------------------------------------------------------------------------
// Maze8
//-----------------------------------------------------------------------------

#declare rez = 8;
#declare rad = 0.5;

#declare Maze = array[6];
#declare Maze[0] = BuildMaze(rez, rez, rad)
#declare Maze[1] = BuildMaze(rez, rez, rad)
#declare Maze[2] = BuildMaze(rez, rez, rad)
#declare Maze[3] = BuildMaze(rez, rez, rad)
#declare Maze[4] = BuildMaze(rez, rez, rad)
#declare Maze[5] = BuildMaze(rez, rez, rad)

#declare MazeCube8 = union {
   object { Maze[0] scale y*0.25 translate -y*rez/2}
   object { Maze[1] scale y*0.25 translate y*rez/2}
   object { Maze[2] scale y*0.25 rotate x*90 translate z*rez/2}
   object { Maze[3] scale y*0.25 rotate x*90 translate -z*rez/2}
   object { Maze[4] scale y*0.25 rotate z*90 translate x*rez/2}
   object { Maze[5] scale y*0.25 rotate z*90 translate -x*rez/2}
   interior { ior 1.5 }
   scale 0.5
   rotate <0, 0, 0>
}

#local _min8 = min_extent(MazeCube8);
union {
   object { MazeCube8 texture { tex } }
   translate <rez*2, floorY-_min8.y, -rez/2>
}

//-----------------------------------------------------------------------------
// Maze5
//-----------------------------------------------------------------------------

#declare rez = 5;
#declare rad = 0.5;

#declare Maze = array[6];
#declare Maze[0] = BuildMaze(rez, rez, rad)
#declare Maze[1] = BuildMaze(rez, rez, rad)
#declare Maze[2] = BuildMaze(rez, rez, rad)
#declare Maze[3] = BuildMaze(rez, rez, rad)
#declare Maze[4] = BuildMaze(rez, rez, rad)
#declare Maze[5] = BuildMaze(rez, rez, rad)

#declare MazeCube5 = union {
   object { Maze[0] scale y*0.25 translate -y*rez/2}
   object { Maze[1] scale y*0.25 translate y*rez/2}
   object { Maze[2] scale y*0.25 rotate x*90 translate z*rez/2}
   object { Maze[3] scale y*0.25 rotate x*90 translate -z*rez/2}
   object { Maze[4] scale y*0.25 rotate z*90 translate x*rez/2}
   object { Maze[5] scale y*0.25 rotate z*90 translate -x*rez/2}
   interior { ior 1.5 }
   scale 0.5
   rotate <0, -25, 0>
}

#local _min5 = min_extent(MazeCube5);
union {
   object { MazeCube5 texture { tex } }  
   translate <rez, floorY-_min5.y, -rez*2>
}

//-----------------------------------------------------------------------------
// Maze3
//-----------------------------------------------------------------------------

#declare rez = 3;
#declare rad = 0.5;

#declare Maze = array[6];
#declare Maze[0] = BuildMaze(rez, rez, rad)
#declare Maze[1] = BuildMaze(rez, rez, rad)
#declare Maze[2] = BuildMaze(rez, rez, rad)
#declare Maze[3] = BuildMaze(rez, rez, rad)
#declare Maze[4] = BuildMaze(rez, rez, rad)
#declare Maze[5] = BuildMaze(rez, rez, rad)

#declare MazeCube3 = union {

   object { Maze[0] scale y*0.25 translate -y*rez/2}
   object { Maze[1] scale y*0.25 translate y*rez/2}
   object { Maze[2] scale y*0.25 rotate x*90 translate z*rez/2}
   object { Maze[3] scale y*0.25 rotate x*90 translate -z*rez/2}
   object { Maze[4] scale y*0.25 rotate z*90 translate x*rez/2}
   object { Maze[5] scale y*0.25 rotate z*90 translate -x*rez/2}

   interior { ior 1.5 }
   scale 0.5
   rotate <0, -155, 0>
}

#local _min3 = min_extent(MazeCube3);
union {
   object { MazeCube3 texture { tex } }
   translate <-rez, floorY-_min3.y, -rez*3> 
}
 
//-----------------------------------------------------------------------------
// Floor
//-----------------------------------------------------------------------------

plane { y, floorY 
   pigment { rgb 2 }
   normal {
      bump_map { png "maze_map" /* "maze_test0" */ interpolate 0 map_type 0 } 
      translate -0.5 
      rotate x*90
      rotate y*35
      scale 50 
      bump_size 100
   }
   finish { diffuse 8 }
}
 
